/**
 * Real Estate Manager Blocks for Gutenberg 
 *
 */
( function( blocks, i18n, element ) {
	var el = element.createElement;
	var __ = i18n.__;
	var Editable = blocks.Editable;
	var AlignmentToolbar = wp.blocks.AlignmentToolbar;
	var BlockControls = wp.blocks.BlockControls;
	var InspectorControls = wp.blocks.InspectorControls;
	var TextControl = wp.components.TextControl;
	var RangeControl = wp.components.RangeControl;
	var PanelColor = wp.components.PanelColor;
	var ColorPalette = wp.components.ColorPalette;
	var SelectControl = wp.components.SelectControl;
	var TextareaControl = wp.components.TextareaControl;

	var blockStyle = {
		backgroundColor: '#003C70',
		textAlign: 'center',
		color: '#fff',
		padding: '20px'
	};

	var blockColors = [ { name: 'red', color: '#f00' }, { name: 'white', color: '#fff' }, { name: 'blue', color: '#00f' } ];

	/**
	 * Agent Login Block
	 * @param  heading, redirect
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/login-agent', {
		title: __( 'Login Agent' ),
		icon: 'admin-users',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('form')
	    ],
		attributes: {
			heading: {
				type: 'string',
				default: 'Login Here'
			},
			redirect: {
				type: 'string',
				default: 'http://site.com/profile'
			},
		},	    
	    edit: function(props) {
	        return [!!props.isSelected && el(
	                wp.editor.InspectorControls, {
	                    key: 'inspector'
	                },
	                el(
	                    TextControl, {
	                        key: 'rem_heading',
	                        type: 'text',
	                        label: __('Title of form'),
	                        value: props.attributes.heading,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                heading: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_redirect',
	                        type: 'url',
	                        label: __('Redirect url after login'),
	                        value: props.attributes.redirect,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                redirect: value
	                            });
	                        },
	                    }
	                ),
	            ),
	            el(
					'p',
					{ style: blockStyle },
					'Agent Login Form. ('+props.attributes.heading+')'
				)
	        ];
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * Register Agent
	 * @param  no params
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/register-agent', {
		title: __( 'Register Agent' ),
		icon: 'welcome-add-page',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('form')
	    ],	    
	    edit: function(props) {
	        return el(
					'p',
					{ style: blockStyle },
					'Register Agent Form.'
				)
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * Simple Search Form Block
	 * @param  heading, redirect
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/simple-search', {
		title: __( 'Simple Search Properties' ),
		icon: 'search',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('search')
	    ],
		attributes: {
			placeholder: {
				type: 'string',
				default: 'Type to Search...'
			},
			width: {
				type: 'string',
				default: '450px'
			},
			border_color: {
				type: 'string',
				default: '#E4E4E4'
			},
			results_page: {
				type: 'string',
				default: 'http://site.com/search-results'
			},
			search_icon: {
				type: 'string',
				default: '<i class="glyphicon glyphicon-search"></i>'
			},
		},	    
	    edit: function(props) {
	        return [!!props.isSelected && el(
	                wp.editor.InspectorControls, {
	                    key: 'inspector'
	                },
	                el(
	                    TextControl, {
	                        key: 'rem_placeholder',
	                        type: 'text',
	                        label: __('Placeholder'),
	                        value: props.attributes.placeholder,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                placeholder: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_width',
	                        type: 'text',
	                        label: __('Width in px'),
	                        value: props.attributes.width,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                width: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_results_page',
	                        type: 'url',
	                        label: __('Search Results Page URL'),
	                        value: props.attributes.results_page,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                results_page: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_search_icon',
	                        type: 'text',
	                        label: __('Search Icon'),
	                        help: __('Font Awesome 5 also supported'),
	                        value: props.attributes.search_icon,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                search_icon: value
	                            });
	                        },
	                    }
	                ),	                
	                el(
	                    PanelColor, {
	                        title: __('Border Color'),
	                        colorValue: props.attributes.border_color,
	                    },
		                el(
		                    ColorPalette, {
		                        key: 'rem_border_color',
		                        colors: blockColors,
		                        value: props.attributes.border_color,
		                        onChange: function(value) {
		                            props.setAttributes({
		                                border_color: value
		                            });
		                        },
		                    }
		                ),	                    
	                ),
	            ),
	            el(
					'p',
					{ style: blockStyle },
					'Simple Search Properties. ('+props.attributes.placeholder+')'
				)
	        ];
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * Search Property
	 * @param  no params
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/search-property', {
		title: __( 'Search Properties' ),
		icon: 'search',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('search')
	    ],	    
		attributes: {
			fields_to_show: {
				type: 'array',
				default: ''
			},
			columns: {
				type: 'string',
				default: '6'
			},
			search_btn_text: {
				type: 'string',
				default: 'Search'
			},
			filters_btn_text: {
				type: 'string',
				default: 'More Filters'
			},
			reset_btn_text: {
				type: 'string',
				default: 'Reset'
			},
			fixed_fields: {
				type: 'string',
				default: ''
			},
			results_page: {
				type: 'string',
				default: ''
			},
			results_selector: {
				type: 'string',
				default: ''
			},
			disable_eq_height: {
				type: 'string',
				default: ''
			},
			agent_id: {
				type: 'string',
				default: ''
			},
			order: {
				type: 'string',
				default: ''
			},
			orderby: {
				type: 'string',
				default: ''
			},
			more_filters_column_class: {
				type: 'string',
				default: 'col-xs-6 col-sm-4 col-md-3'
			},
		},	    
	    edit: function(props) {
	        return [!!props.isSelected && el(
	                wp.editor.InspectorControls, {
	                    key: 'inspector'
	                },
	                el(
	                    SelectControl, {
	                        key: 'rem_fields',
	                        multiple: true,
	                        options: rem_db_settings.property_search_fields,
	                        label: __('Choose fields to show'),
	                        value: props.attributes.fields_to_show,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                fields_to_show: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_columns',
	                        options: [
	                        	{label: __('1 Column'), value: '12'},
	                        	{label: __('2 Columns'), value: '6'},
	                        	{label: __('3 Columns'), value: '4'},
	                        	{label: __('4 Columns'), value: '3'},
	                        	{label: __('5 Columns'), value: '5th-1'},
	                        ],
	                        label: __('Columns'),
	                        value: props.attributes.columns,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                columns: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_search_btn_text',
	                        type: 'text',
	                        label: __('Search Button Label'),
	                        value: props.attributes.search_btn_text,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                search_btn_text: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_filters_btn_text',
	                        type: 'text',
	                        label: __('Filter Button Label'),
	                        value: props.attributes.filters_btn_text,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                filters_btn_text: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_reset_btn_text',
	                        type: 'text',
	                        label: __('Reset Button Label'),
	                        value: props.attributes.reset_btn_text,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                reset_btn_text: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextareaControl, {
	                        key: 'rem_fixed_fields',
	                        type: 'text',
	                        label: __('Fixed Fields'),
	                        help: __('field_key|value per line to filter specific results'),
	                        value: props.attributes.fixed_fields,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                fixed_fields: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_results_page',
	                        type: 'url',
	                        label: __('Search Results Page URL'),
	                        help: __('It will disable AJAX'),
	                        value: props.attributes.results_page,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                results_page: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_results_selector',
	                        type: 'text',
	                        label: __('Results Selector'),
	                        help: __('HTML selector for displaying results on same page but different location'),
	                        value: props.attributes.results_selector,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                results_selector: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_more_filters_column_class',
	                        type: 'text',
	                        label: __('More Filters Columns Class'),
	                        value: props.attributes.more_filters_column_class,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                more_filters_column_class: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_agent_id',
	                        type: 'text',
	                        label: __('Agent ID'),
	                        help: __('Provide agent id to display properties specific to that agent'),
	                        value: props.attributes.agent_id,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                agent_id: value
	                            });
	                        },
	                    }
	                ),
	            ),
	            el(
					'p',
					{ style: blockStyle },
					'Search Property Form. ('+props.attributes.fields_to_show+')'
				)
	        ];
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * Create Property
	 * @param  null
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/create-property', {
		title: __( 'Create Property' ),
		icon: 'welcome-add-page',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('submit')
	    ],    
	    edit: function(props) {
	        return el(
					'p',
					{ style: blockStyle },
					'Create Property.'
				)
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * Edit Property
	 * @param  null
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/edit-property', {
		title: __( 'Edit Property' ),
		icon: 'edit',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('form')
	    ],    
	    edit: function(props) {
	        return el(
					'p',
					{ style: blockStyle },
					'Edit Property.'
				)
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * My Properties
	 * @param  null
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/my-properties', {
		title: __( 'My Properties' ),
		icon: 'list-view',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('list')
	    ],    
	    edit: function(props) {
	        return el(
					'p',
					{ style: blockStyle },
					'My Properties.'
				)
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});

	/**
	 * List Properties
	 * @param  heading, redirect
	 * @return {null}       Rendered through PHP
	 */
	blocks.registerBlockType( 'real-estate-manager/list-properties', {
		title: __( 'List Properties' ),
		icon: 'list-view',
		category: 'rem',
	    keywords: [
            __('Real Estate Manager'),
            __('REM'),
            __('list')
	    ],
		attributes: {
			order: {
				type: 'string',
				default: 'ASC'
			},
			orderby: {
				type: 'string',
				default: 'date'
			},
			style: {
				type: 'string',
				default: '1'
			},
			posts: {
				type: 'string',
				default: '10'
			},
			class: {
				type: 'string',
				default: 'col-sm-12'
			},
			author: {
				type: 'string',
				default: ''
			},
			tags: {
				type: 'string',
				default: ''
			},
			pagination: {
				type: 'string',
				default: 'enable'
			},
			meta: {
				type: 'string',
				default: ''
			},
			top_bar: {
				type: 'string',
				default: 'disable'
			},
			default_grid_style: {
				type: 'string',
				default: '3'
			},
			nearest_porperties: {
				type: 'string',
				default: 'disable'
			},
		},	    
	    edit: function(props) {
	        return [!!props.isSelected && el(
	                wp.editor.InspectorControls, {
	                    key: 'inspector'
	                },
	                el(
	                    SelectControl, {
	                        key: 'rem_order',
	                        type: 'text',
	                        options: [
	                        	{label: __('Ascending'), value: 'ASC'},
	                        	{label: __('Descending'), value: 'DESC'},
	                        ],
	                        label: __('Order'),
	                        value: props.attributes.order,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                order: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_orderby',
	                        type: 'text',
	                        options: [
	                        	{label: __('Date'), value: 'date'},
	                        	{label: __('Agent'), value: 'author'},
	                        	{label: __('Property Title'), value: 'title'},
	                        	{label: __('Property Price'), value: 'price'},
	                        	{label: __('Random'), value: 'rand'},
	                        ],
	                        label: __('Order'),
	                        value: props.attributes.orderby,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                orderby: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_style',
	                        type: 'text',
	                        options: [
	                        	{label: __('1'), value: '1'},
	                        	{label: __('2'), value: '2'},
	                        	{label: __('3'), value: '3'},
	                        	{label: __('4'), value: '4'},
	                        	{label: __('5'), value: '5'},
	                        	{label: __('6'), value: '6'},
	                        	{label: __('7'), value: '7'},
	                        ],
	                        label: __('Style'),
	                        value: props.attributes.style,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                style: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_posts',
	                        type: 'text',
	                        label: __('Number of Properties'),
	                        help: __('Provide -1 for all'),
	                        value: props.attributes.posts,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                posts: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_class',
	                        type: 'text',
	                        options: [
	                        	{label: __('1 Column'), value: 'col-sm-12'},
	                        	{label: __('2 Columns'), value: 'col-sm-6'},
	                        	{label: __('3 Columns'), value: 'col-sm-4'},
	                        	{label: __('4 Columns'), value: 'col-sm-3'},
	                        	{label: __('5 Columns'), value: 'col-sm-5th-1'},
	                        ],
	                        label: __('Columns'),
	                        value: props.attributes.class,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                class: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_author',
	                        type: 'text',
	                        label: __('Agent ID'),
	                        help: __('Provide agent id to pull properties of that agent'),
	                        value: props.attributes.author,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                author: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextControl, {
	                        key: 'rem_tags',
	                        type: 'text',
	                        label: __('Tags'),
	                        help: __('Comma separated tags'),
	                        value: props.attributes.tags,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                tags: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_pagination',
	                        type: 'text',
	                        options: [
	                        	{label: __('Enable'), value: 'enable'},
	                        	{label: __('Disable'), value: 'disable'},
	                        ],
	                        label: __('Pagination'),
	                        value: props.attributes.pagination,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                pagination: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    SelectControl, {
	                        key: 'rem_top_bar',
	                        type: 'text',
	                        options: [
	                        	{label: __('Enable'), value: 'enable'},
	                        	{label: __('Disable'), value: 'disable'},
	                        ],
	                        label: __('Top Bar'),
	                        value: props.attributes.top_bar,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                top_bar: value
	                            });
	                        },
	                    }
	                ),
	                el(
	                    TextareaControl, {
	                        key: 'rem_meta',
	                        type: 'text',
	                        label: __('Filter Properties'),
	                        help: __('field_key|value per line to filter specific results'),
	                        value: props.attributes.meta,
	                        onChange: function(value) {
	                            props.setAttributes({
	                                meta: value
	                            });
	                        },
	                    }
	                ),
	            ),
	            el(
					'p',
					{ style: blockStyle },
					'Properties List.'
				)
	        ];
	    },
		save: function() {
			// Rendering in PHP
			return null;
		},
	});	

} )(
	window.wp.blocks,
	window.wp.i18n,
	window.wp.element
);